.. _installation:

Installation
============

Install Flask-SSO with ``pip`` ::

    pip install flask-sso

The development version can be downloaded from `its page at GitHub
<http://github.com/inveniosoftware/flask-sso>`_. ::

    git clone https://github.com/inveniosoftware/flask-sso.git
    cd flask-sso
    python setup.py develop
    source run-tests.sh

Requirements
------------
Flask-SSO has the following dependencies:

* `Flask <https://pypi.python.org/pypi/Flask>`_
* `six <https://pypi.python.org/pypi/six>`_

Flask-SSO requires Python version 2.6, 2.7 or 3.3+
